@@ -240,7 +240,7 @@ class dyn_obj:
             for i in range(len(frames)):
                 cur_frame = frames[i]
 
-                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]+1) * cur_frame
+                bpy.data.objects[name].data.bevel_factor_end = 1/(frames[-1]+1) * (cur_frame-1)
                 bpy.data.objects[name].data.keyframe_insert(data_path='bevel_factor_end', frame=cur_frame)
             
 
